@@ -1,10 +1,10 @@
 package MooseX::MethodAttributes::Role::Meta::Role;
-our $VERSION = '0.11_02';
+our $VERSION = '0.11_03';
 
 # ABSTRACT: metarole role for storing code attributes
 
 use Moose::Util::MetaRole;
-use Moose::Util qw/find_meta ensure_all_roles/;
+use Moose::Util qw/find_meta does_role ensure_all_roles/;
 use Carp qw/croak/;
 
 use Moose::Role;
@@ -37,12 +37,18 @@ around method_metaclass => sub {
 around 'apply' => sub {
     my ($orig, $self, $thing) = @_;
     if ($thing->isa('Moose::Meta::Class')) {
-        Moose::Util::MetaRole::apply_metaclass_roles(
-            for_class => $thing->name,
-            metaclass_roles => ['MooseX::MethodAttributes::Role::Meta::Class'],
-            method_metaclass_roles => ['MooseX::MethodAttributes::Role::Meta::Method'],
-            wrapped_method_metaclass_roles => ['MooseX::MethodAttributes::Role::Meta::Method::MaybeWrapped'],
-        );
+        unless (
+           does_role($thing, 'MooseX::MethodAttributes::Role::Meta::Class')
+        && does_role($thing->method_metaclass, 'MooseX::MethodAttributes::Role::Meta::Method')
+        && does_role($thing->wrapped_method_metaclass, 'MooseX::MethodAttributes::Role::Meta::Method::MaybeWrapped')) {
+        
+            Moose::Util::MetaRole::apply_metaclass_roles(
+                for_class => $thing->name,
+                metaclass_roles => ['MooseX::MethodAttributes::Role::Meta::Class'],
+                method_metaclass_roles => ['MooseX::MethodAttributes::Role::Meta::Method'],
+                wrapped_method_metaclass_roles => ['MooseX::MethodAttributes::Role::Meta::Method::MaybeWrapped'],
+            );
+        }
     }
     elsif ($thing->isa('Moose::Meta::Role')) {
         Moose::Util::MetaRole::apply_metaclass_roles(
@@ -86,7 +92,7 @@ MooseX::MethodAttributes::Role::Meta::Role - metarole role for storing code attr
 
 =head1 VERSION
 
-version 0.11_02
+version 0.11_03
 
 =head1 SYNOPSIS
 
